pub enum Kind {
Circle {
radius: f64,
},
Rect {
width: f64,
height: f64,
},
}Expand description
A circle or a rectangle.
Variants
Circle
BYRADIUS, and every GEORADIUS form.
Rect
BYBOX, which is an axis aligned rectangle and not a box on the hash
grid. The two have nothing to do with each other.