pub struct Held<'a, T> { /* private fields */ }Expand description
The lock, held.
Derefs to the value, and gives it back when it is dropped. It cannot be sent to another thread, because the thread that took a lock is the thread that has to release it.