#[non_exhaustive]#[repr(u8)]pub enum Space {
Inline = 0,
Arena = 1,
Log = 2,
Hash = 3,
Set = 4,
ZSet = 5,
List = 6,
Stream = 7,
Doc = 8,
Vector = 9,
Graph = 10,
}Expand description
Which world an Addr offset points into.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Inline = 0
The value is the 52 bits. Small integers and short strings live entirely
inside the index entry and cost zero dereferences. This is what Redis
calls int encoding and part of what it calls embstr.
Arena = 1
A byte offset into the shard’s arena segments (05 section 3).
Log = 2
A byte offset into the shard’s log region (06 section 2).
Hash = 3
A hash, as an owner local element table.
Set = 4
A set, as an owner local element table or a dense member vector.
ZSet = 5
A sorted set, as a counted B+ tree.
List = 6
A list, as a ring deque.
Stream = 7
A stream, as a radix log.
Doc = 8
A document, with its path indexes.
Vector = 9
A vector partition set.
Graph = 10
Graph adjacency.
Implementations