pub fn bytes_eq(a: &[u8], b: &[u8]) -> bool
Whether a and b hold the same bytes.
a
b
The same answer as a == b and the same cost model as memcmp for a long string, without the call for a short one.
a == b
memcmp