encode

Function encode 

pub fn encode(lon: f64, lat: f64, step: u8) -> Option<Hash>
The hash of a point at a given precision.

Nothing at all for a point outside the projection, which is the only way this fails. step is between 1 and STEP_MAX.